package
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Sep 5, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
A Formatter implementation for logging on GKE
Documentation
¶
type GKELogFormatter struct {
TimestampFormat string
}
GKELogFormatter formats messages for use to output to stdout on a container on GKE.
Format formats log so Stackdriver Logging can construe.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.